R/visualization.R
RunAndProjectUMAP.RdThis is a wrapper function that builds on the ProjectUMAP() function, which allows users to generate UMAP for a subset of the data (e.g., cells from a sketched assay), and then project this UMAP to any other data.
RunAndProjectUMAP(
object,
nn.name = NULL,
k.nn = 5,
landmark.assay.name = "LANDMARK",
reduction.name = "sketched.umap",
verbose = TRUE,
...
)a Seurat object
the name of the Neighbor object used to generate the UMAP.
the number of neighbors used to generate the UMAP. If it exceeds the number of k in the nn.name object, will be ignored.
the name of the sketched assay
the name of the UMAP to be stored; Note that the projected UMAP will be named as "proj.'reduction.name'".
Print progress status
other parameters that are accepted by RunUMAP() or ProjectUMAP()
return a Seurat object that contains a UMAP of the sketched assay and a UMAP of the full data