A wrapper function that finds Multi-Modal weights and generate a Multi-Modal NN object.
FindmmNN(
object,
sketch.assay = NULL,
reduction.list,
dims.list,
k.nn = 20,
knn.range = 200,
l2.norm = TRUE,
fix.wnn.weights = NULL,
weighted.nn.name = "weighted.nn",
verbose = TRUE,
...
)A Seurat object
The name of the sketched assay of the landmark cells.
A list of dimensional reductions, one for each modality
A list containing the dimensions for each reduction to use
The number of nearest neighbors to compute for each modality. Internally clamped to a minimum of 20 (i.e. values below 20 are silently raised to 20).
Range parameter for nearest neighbor search
Perform L2 normalization on the cell embeddings
Pre-specified modality weights. If provided, skips the calculation and uses these weights directly. Should be a list with the same length as reduction.list.
Multimodal neighbor object name
Print progress bars and output
Arguments passed to other methods
return a Seurat object that contains a weighted.nn Neighbor object between the landmark cells and all the other cells.
This function is essentially a wrapper function that perform the following 2 procedures:
Seurat:::FindModalityWeights
Seurat:::MultiModalNN