Run diffusion map dimensionality reduction on single-cell data.
RunDiffusionMap(object, ...)
# Default S3 method
RunDiffusionMap(
object,
assay = NULL,
metric = "cosine",
distance.matrix = NULL,
ncomp = 20,
reduction.name = "DiffMap",
reduction.key = "DC_",
weight.by.var = TRUE,
verbose = TRUE,
seed.use = 101,
...
)
# S3 method for class 'Assay'
RunDiffusionMap(
object,
assay = NULL,
features = NULL,
ncomp = 20,
metric = "cosine",
distance.matrix = NULL,
reduction.name = "DiffMap",
reduction.key = "DC_",
weight.by.var = TRUE,
verbose = TRUE,
seed.use = 101,
...
)
# S3 method for class 'StdAssay'
RunDiffusionMap(
object,
assay = NULL,
features = NULL,
layer = "scale.data",
ncomp = 20,
metric = "cosine",
distance.matrix = NULL,
reduction.name = "DiffMap",
reduction.key = "DC_",
weight.by.var = TRUE,
verbose = TRUE,
seed.use = 101,
...
)
# S3 method for class 'Seurat'
RunDiffusionMap(
object,
assay = NULL,
features = NULL,
layer = "scale.data",
ncomp = 20,
metric = "cosine",
distance.matrix = NULL,
reduction.name = "DiffMap",
reduction.key = "DC_",
weight.by.var = TRUE,
verbose = TRUE,
seed.use = 101,
...
)An object to run diffusion map on
Additional arguments to be passed to DiffusionMap()
Name of Assay diffusion map is being run on
This determines the choice of metric used to measure distance in the input space. Check DiffusionMap() for details. If a distance.matrix is provided, this will be ignored.
If set, runs DiffusionMap on the given distance matrix instead of data matrix.
Number of components to compute
the name of the DimReduc object
dimensional reduction key, specifies the string before the number for the dimension names.
Weight the cell embeddings by the eigenvalues of the diffusion map
To print diagnostic messages. Default is TRUE.
Set a random seed. Setting NULL will not set a seed.
Features to compute Diffusion Map
The layer in assay to use when running diffusion map analysis.
Returns a DimReduc object with diffusion map results
if (FALSE) { # \dontrun{
# Run diffusion map on a Seurat object
seurat_obj <- RunDiffusionMap(seurat_obj, ncomp = 10)
} # }